/*Create database first*/
CREATE DATABASE LogTest
GO
USE LogTest
GO
 
 /*Get DB id*/
 SELECT DB_ID()

GO
/*Create Log Table*/
  IF OBJECT_ID('dbo.LogData') IS  NULL
	CREATE TABLE dbo.LogData 
	(sql_text NVARCHAR(1000),[log_datetime] DATETIME,[message] NVARCHAR(100))
  
   

GO

 /*Create extended event session*/
CREATE EVENT SESSION LogTestSession ON SERVER 
    ADD EVENT sqlserver.error_reported  -- ,
      (
      ACTION (sqlserver.sql_text, sqlserver.tsql_stack, sqlserver.database_id,sqlserver.username)
       WHERE sqlserver.database_id = 33  AND [error_number]=50000 /*Filter error no or db number*/
	   )   
    ADD TARGET package0.ring_buffer    
        (SET max_memory = 4096 
		) 
WITH (max_dispatch_latency = 1 seconds)

/*Lets start session*/
ALTER EVENT SESSION LogTestSession ON SERVER
STATE = START

/*Lets put user message*/
 
DECLARE @Message VARCHAR(100) = 'Hello word message '+ CONVERT(VARCHAR(20),GETDATE(),20)
RAISERROR(  @Message,1,1);
SELECT CONVERT(VARCHAR(20),GETDATE(),20)
 
GO
 
DECLARE @Message VARCHAR(100) = 'Log message '+ CONVERT(VARCHAR(20),GETDATE(),20)
RAISERROR(  @Message,1,1);
SELECT CONVERT(VARCHAR(20),GETDATE(),20)
 



 /*Parse data from extended events*/            
 
 IF OBJECT_ID('tempdb.dbo.#LogData') IS NOT NULL
	DROP TABLE #LogData;
 
 SELECT
        CAST(LocksAcquired.TargetXml AS XML)  AS XMLData
    INTO
        #LogData
    FROM
        (
        SELECT
                CAST(t.target_data AS XML)  AS TargetXml 
            FROM
                     sys.dm_xe_session_targets  AS t
                JOIN sys.dm_xe_sessions         AS s

                    ON s.address = t.event_session_address
            WHERE
             
                s.name        = 'LogTestSession'
        )
            AS LocksAcquired;

 



 /*Put it to log table */     
 
INSERT INTO  dbo.LogData  	(sql_text ,[log_datetime] ,[message]  )
SELECT
		 T.XMLData.value('(action[@name="sql_text"])[1]',
            'varchar(1000)'     )  AS [SqlText],
         T.XMLData.value('(@timestamp)[1]',
            'datetime'     )  AS [OccurredDtTm],
         T.XMLData.value('(data[@name="message"])[1]',
            'varchar(60)'     )  AS [Message]
    FROM
        #LogData
    CROSS APPLY XMLData.nodes('/RingBufferTarget/event[@name="error_reported"]')  AS T(XMLData);


/*Get result*/
SELECT * FROM dbo.LogData 


/*Cleanup data*/
IF EXISTS (SELECT *
      FROM sys.server_event_sessions  
     WHERE name = 'LogTestSession')
BEGIN
    DROP EVENT SESSION LogTestSession
          ON SERVER;    
END